@@ -7,6 +7,7 @@ from fabric.operations import require
 from fabric.tasks import Task
 import os
 
+import deploytool
 
 class ProvisioningTask(Task):
     """
@@ -96,8 +97,8 @@ class Setup(ProvisioningTask):
         project_user = str.join('', [env.project_name_prefix, env.project_name])
 
         # locations of local folders (based on running fabfile.py) needed for remote file transfers
-        local_scripts_path = os.path.join(os.path.dirname(env.real_fabfile), 'deploytool', 'scripts')
-        local_templates_path = os.path.join(os.path.dirname(env.real_fabfile), 'deploytool', 'templates')
+        local_scripts_path = os.path.join(os.path.dirname(deploytool.__file__), 'scripts')
+        local_templates_path = os.path.join(os.path.dirname(deploytool.__file__), 'templates')
 
         # locations of remote paths
         user_home_path = os.path.join('/', 'home', project_user)
